@@ -10,6 +10,7 @@ from concurrent.futures import ProcessPoolExecutor
 import cv2
 import numpy as np
 
+
 # import open3d as o3d
 # import numpy as np
 # import pylas
@@ -33,8 +34,6 @@ class Task:
             raise ValueError('Invalid key')
         self.__TOKEN_AK = token_ak
         self.__TOKEN_SK = token_sk
-        # self.__TOKEN_AK = 'ae1bdbc2d15e4fb4779558f75de21c95'
-        # self.__TOKEN_SK = '29de907568f60c9a452f24ef1e0a03b0'
 
     def __getToken(self):
         data = {
@@ -178,7 +177,7 @@ class DrawPic:
             (mark['point']['left'], mark['point']['top'], mark['point']['right'], mark['point']['bottom']),
             fill=color, outline=outline_color)
 
-    def do_mosaic(self, x, y, w, h, neighbor=5):
+    def do_mosaic(self, points, neighbor=5):
         """
         马赛克的实现原理是把图像上某个像素点一定范围邻域内的所有点用邻域内左上像素点的颜色代替，这样可以模糊细节，但是可以保留大体的轮廓。
         :param frame: opencv frame
@@ -188,19 +187,21 @@ class DrawPic:
         :param int h:  马赛克高
         :param int neighbor:  马赛克每一块的宽
         """
-        frame = cv2.cvtColor(np.asarray(self._im), cv2.COLOR_RGB2BGR)
-        neighbor = w // 10
-        fh, fw = frame.shape[0], frame.shape[1]
-        if (y + h > fh) or (x + w > fw):
-            return
-        for i in range(0, h - neighbor, neighbor):  # 关键点0 减去neightbour 防止溢出
-            for j in range(0, w - neighbor, neighbor):
-                rect = [j + x, i + y, neighbor, neighbor]
-                color = frame[i + y][j + x].tolist()  # 关键点1 tolist
-                left_up = (rect[0], rect[1])
-                right_down = (rect[0] + neighbor - 1, rect[1] + neighbor - 1)  # 关键点2 减去一个像素
-                cv2.rectangle(frame, left_up, right_down, color, -1)
-        self._im = Image.fromarray(cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))
+        for point in points:
+            x, y, w, h = point
+            frame = cv2.cvtColor(np.asarray(self._im), cv2.COLOR_RGB2BGR)
+            neighbor = w // 10
+            fh, fw = frame.shape[0], frame.shape[1]
+            if (y + h > fh) or (x + w > fw):
+                return
+            for i in range(0, h - neighbor, neighbor):  # 关键点0 减去neightbour 防止溢出
+                for j in range(0, w - neighbor, neighbor):
+                    rect = [j + x, i + y, neighbor, neighbor]
+                    color = frame[i + y][j + x].tolist()  # 关键点1 tolist
+                    left_up = (rect[0], rect[1])
+                    right_down = (rect[0] + neighbor - 1, rect[1] + neighbor - 1)  # 关键点2 减去一个像素
+                    cv2.rectangle(frame, left_up, right_down, color, -1)
+            self._im = Image.fromarray(cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))
 
 
 class Executor:
@@ -263,18 +264,19 @@ class Tools:
                 if pro['pcode'] != pro['prevcode']:
                     self.getAttr(propArr, tmp, pro['pcode'])
 
-    def getExtraValue(self, propArr, pcode):
+    ''' propArr = mark['property'][0] '''
+
+    def getExtraValue(self, propArr, parentid):
         data = {}
         for pro in propArr:
-            if pro['prevcode'] == pcode or not pro['prevcode']:
+            if pro['prevcode'] == parentid or not pro['prevcode']:
                 data[pro['pname']] = pro['pcode']
-        for k, v in data.items():
+        for pname, pcode in data.items():
             tmp = []
-            self.getAttr(propArr, tmp, v)
-            data[k] = tmp
+            self.getAttr(propArr, tmp, pcode)
+            data[pname] = tmp
         return data
 
-
 # class PointCloud:
 #     """点云处理"""
 #
